@@ -12,29 +12,18 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# oslosphinx uses reno and reno uses oslosphinx. Make oslosphinx for
-# reno optional to break the build cycle
-try:
-    import openstackdocstheme  # noqa
-except ImportError:
-    has_theme = False
-else:
-    has_theme = True
-
 
 # -- General configuration ----------------------------------------------------
 
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
 extensions = [
+    'openstackdocstheme',
     'sphinx.ext.autodoc',
     'reno.sphinxext',
     'reno._exts.show_reno_config',
 ]
 
-if has_theme:
-    extensions.append('openstackdocstheme')
-
 # The master toctree document.
 master_doc = 'index'
 
@@ -43,7 +32,7 @@ project = u'reno'
 copyright = u'2013, OpenStack Foundation'
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+pygments_style = 'native'
 
 # Do not warn about non-local image URI
 suppress_warnings = ['image.nonlocal_uri']
@@ -51,9 +40,7 @@ suppress_warnings = ['image.nonlocal_uri']
 
 # -- openstackdocstheme configuration -----------------------------------------
 
-if has_theme:
-    html_theme = 'openstackdocs'
+html_theme = 'openstackdocs'
 
-repository_name = 'openstack/reno'
-bug_project = '933'
-bug_tag = 'docs'
+openstackdocs_repo_name = 'openstack/reno'
+openstackdocs_use_storyboard = True
