@@ -10,29 +10,18 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from __future__ import print_function
-
 import logging
 
 from reno import loader
-from reno import utils
 
 LOG = logging.getLogger(__name__)
 
 
-def list_cmd(args):
+def list_cmd(args, conf):
     "List notes files based on query arguments"
     LOG.debug('starting list')
-    reporoot = args.reporoot.rstrip('/') + '/'
-    notesdir = utils.get_notes_dir(args)
-    collapse = args.collapse_pre_releases
-    ldr = loader.Loader(
-        reporoot=reporoot,
-        notesdir=notesdir,
-        branch=args.branch,
-        collapse_pre_releases=collapse,
-        earliest_version=args.earliest_version,
-    )
+    reporoot = conf.reporoot
+    ldr = loader.Loader(conf)
     if args.version:
         versions = args.version
     else:
