@@ -119,16 +119,35 @@ class Loader(object):
 
         cleaned_content = {}
 
+        if not isinstance(content, dict):
+            LOG.warning(
+                '%s does not appear to be structured as a YAML mapping. '
+                'Did you forget a top-level key?',
+                filename,
+            )
+            raise ValueError(
+                f'{filename} does not appear to be structured as a YAML '
+                f'mapping. Did you forget a top-level key?'
+            )
+
         for section_name, section_content in content.items():
             if section_name == self._config.prelude_section_name:
                 if not isinstance(section_content, str):
                     LOG.warning(
-                        ('The %s section of %s '
-                         'does not parse as a single string. '
-                         'Is the YAML input escaped properly?') %
-                        (self._config.prelude_section_name, filename),
+                        'The %s section of %s does not parse as a single '
+                        'string. Is the YAML input escaped properly?',
+                        section_name, filename,
                     )
             else:
+                if section_name not in dict(self._config.sections):
+                    # TODO(stephenfin): Make this an error in a future release
+                    LOG.warning(
+                        'The %s section of %s is not a recognized section. '
+                        'It should be one of: %s. '
+                        'This will be an error in a future release.',
+                        section_name, filename,
+                        ', '.join(dict(self._config.sections)),
+                    )
                 if isinstance(section_content, str):
                     # A single string is OK, but wrap it with a list
                     # so the rest of the code can treat the data model
@@ -136,21 +155,20 @@ class Loader(object):
                     section_content = [section_content]
                 elif not isinstance(section_content, list):
                     LOG.warning(
-                        ('The %s section of %s '
-                         'does not parse as a string or list of strings. '
-                         'Is the YAML input escaped properly?') % (
-                             section_name, filename),
+                        'The %s section of %s does not parse as a string or '
+                        'list of strings. Is the YAML input escaped properly?',
+                        section_name, filename,
                     )
                 else:
                     for item in section_content:
                         if not isinstance(item, str):
                             LOG.warning(
-                                ('The item %r in the %s section of %s '
-                                 'parses as a %s instead of a string. '
-                                 'Is the YAML input escaped properly?'
-                                 ) % (item, section_name,
-                                      filename, type(item)),
+                                'The item %r in the %s section of %s parses '
+                                'as a %s instead of a string. '
+                                'Is the YAML input escaped properly?',
+                                item, section_name, filename, type(item),
                             )
+
             cleaned_content[section_name] = section_content
 
         return cleaned_content
